pub fn predict(
signatures: &[EditOpSignature],
graph: &CausalGraph,
config: &CeaConfig,
) -> CausalPredictionExpand description
Predict correctness from patch topology using the causal graph.
pub fn predict(
signatures: &[EditOpSignature],
graph: &CausalGraph,
config: &CeaConfig,
) -> CausalPredictionPredict correctness from patch topology using the causal graph.