Module store

Module store 

Enums

UpdateResult

Functions

load_graph
Load the causal graph from the store into memory.
load_graph_with_tx
Load the causal graph from an already-open transaction handle.
update_graph
Update the causal graph from an attributed run result.
update_graph_with_tx
Update the causal graph using an already-open transaction handle.