pub enum HypothesisEdgeKind {
CausesRegression,
FixesFailure,
AssociatedWithStableFailure,
}Expand description
What kind of causal relationship a hypothesis edge represents.
Variants
CausesRegression
The edit causes a regression (new failure in patched).
FixesFailure
The edit fixes a failure (failure in baseline, absent in patched).
AssociatedWithStableFailure
The edit is associated with a failure that is stable across both.