pub struct EffectRelationLineageHint {
pub source: EffectRelationLineageSource,
pub kind: EffectKind,
pub file: Option<PathBuf>,
pub line: Option<u32>,
pub message: String,
pub in_baseline: bool,
pub in_patched: bool,
pub supersedes_relation_version_id: RelationVersionId,
}Expand description
Explicit relation-lineage hint for an effect-derived export relation.
Fields
source: EffectRelationLineageSourceWhich effect export family this hint applies to.
kind: EffectKindEffect kind to match.
file: Option<PathBuf>Effect file to match.
line: Option<u32>Effect line to match.
message: StringEffect message to match.
in_baseline: boolWhether the effect was present in the baseline execution.
in_patched: boolWhether the effect was present in the patched execution.
supersedes_relation_version_id: RelationVersionIdReal prior relation version when known.