Module scoring

Module scoring 

Objective-driven scoring policy.

Structs

ObjectivePolicy
Policy for how scores are combined for a given objective.
PatchExecutionPlan
Frozen execution plan with classified checks.
PlannedCheck
A classified check in an execution plan.

Enums

ComparabilityClass
Check comparability classification.
ObjectiveKind
What kind of objective the patch is trying to achieve.