Functions
- refuse_
to_ open_ db - Refuses to open a database that is not a verified Forge DB.
- validate_
cea_ no_ raw_ source - Validates that a CEA node contains no raw source code. Checks recursively through all nested objects and arrays.
- validate_
forbidden_ paths - Validates that patches do not touch forbidden paths.
- validate_
patch_ caps - Validates patch caps (max files, max total lines, max lines per file).